#!/usr/bin/env lua
filekl='pm8058-keypad.kl'
filekcm='pm8058-keypad.kcm'
filetranslations='translations.txt'

-- read kl file
invkl={}
for l in io.lines(filekl) do
	local code,keycodelabel=string.match(l,"^key%s+(%d+)%s+(%S+)")
	if code then
		invkl[keycodelabel]=code
	end
end

-- read kcm file
kcm={}
do
	local curkey=nil
	for l in io.lines(filekcm) do
		keycodelabel=string.match(l,"^key%s+(%S+)%s+{")
		if keycodelabel then
			curkey=keycodelabel
		elseif string.find(l,"}") then
			curkey=nil	
		elseif curkey then
			modlist,sym=string.match(l,"^%s*([^:]+):%s+(.-)%s*$")
			if modlist then
				for mod in string.gmatch(modlist,"[^%s ,]+") do
					if mod~="label" and mod~="number" then
						local t=kcm[curkey] or {}
						t[mod]=sym
						kcm[curkey]=t
					end
				end
			end
		end
	end
end

-- read translations file
translations={}
for l in io.lines(filetranslations) do
	local orig,dest=string.match(l,"^(.-)%s*(%S+)$")
	if orig then
		translations[orig]=dest
	end
end

-- do the magic
print("keymaps 0-2,4,6,8-9,12")
print("strings as usual")
for k,v in pairs(kcm) do
	local code=invkl[k]
	if code then
		local base=v["base"]  or "nul"
		local shift=v["shift"] or base
		local alt=v["alt"] or base
		local shiftalt=v["shift+alt"] or shift
		base=translations[base] or "nul"
		shift=translations[shift] or "nul"
		alt=translations[alt] or "nul"
		shiftalt=translations[shiftalt] or "nul"
		print("keycode " .. code .. " = " .. base .. " " .. shift .. " " .. alt .. " " .. shiftalt)
	end
end
standalone={
	["DEL"]="BackSpace",
	["ALT_LEFT"]="AltGr",
	["SHIFT_LEFT"]="Shift",
	["MENU"]="PageUp",
	["HOME"]="Home",
	["BACK"]="PageDown",
	["CAMERA"]="Camera",
	["FOCUS"]="nul",
	["VOLUME_UP"]="VolumeUp",
	["VOLUME_DOWN"]="VolumeDown",
	["DPAD_LEFT"]="Left",
	["DPAD_RIGHT"]="Right",
	["DPAD_UP"]="Up",
	["DPAD_DOWN"]="Down",
}
for k,v in pairs(standalone) do
	local code=invkl[k]
	if code then
		print("keycode " .. code .. " = " .. v)
	end
end

